/// <reference path="avd.string-extensions.js" />
/// <reference path="jquery-1.8.3-vsdoc.js" />
"use strict";


function onDeviceReady() {
    console.log('onDeviceReady');
    document.addEventListener("backbutton", function () {
        console.log('backbutton pressed, activePage id: ' + $.mobile.activePage.attr('id'));
        if ($.mobile.activePage.attr('id') === 'home') {
            navigator.app.exitApp();
        } else {
            navigator.app.backHistory();
        }
    }, false);
}

function onLoad() {
    document.addEventListener("deviceready", onDeviceReady, false);
}

var serviceURL = "http://www.svhonselersdijk.nl/api/";

function initElftallenSelectList() {
    $.getJSON(serviceURL + 'elftal', function (data) {
        var $select = $('#select-elftal').empty();
        $select.append('<option>- Kies een team -</option>');
        $.each(data, function (index, elftal) {
            $select.append('<option value="' + elftal.WpTeamID + '">' + elftal.Naam + '</option>');
        });

        var team = localStorage.getItem('avd.settings.WpTeamID');
        if (team && team !== 0) {
            $select.val(team);
            $('#btnMijnTeam span').text('Mijn team - ' + $select.find('option:selected').text());
        }
    });
}

(function ($) {
    $.fn.extend({
        highlightHonselersdijk: function () {
            $('div:contains("Honselersdijk")', this).each(function () {
                $(this).css({
                    color: '#FF700e', fontWeight: 'bold'
                });
            });
            return this;
        }
    });
}(jQuery));

function getNieuwsList() {
    $.getJSON(serviceURL + 'nieuwsbericht', function (data) {
        $('#nieuwsList li').remove();
        var $list = $('#nieuwsList'), currentDate = '';
        $.each(data, function (index, bericht) {
            if (currentDate !== bericht.DatumNL) {
                currentDate = bericht.DatumNL;
                $list.append('<li data-role="list-divider" data-divider-theme="a">' + currentDate + '</li>');
            }

            $list.append('<li>'
                + '<a href="#nieuwsDetails" data-nieuws-id="' + bericht.ID + '">'
                + (bericht.FotoThumb100
                    ? '<img class="ui-li-thumb" width="100" src="' + bericht.FotoThumb100 + '">'
                    : '')
                    + '<h4>' + bericht.Titel + '</h4>'
                    + '</a></li>');
        });

        $('#nieuwsList').listview('refresh');
    }).error(function (err) { console.error('Fout bij aanspreken webservice', err); });
}

function getGastenboekList() {
    $.getJSON(serviceURL + 'gastenboekbericht', function (data) {
        $('#gastenboekList li').remove();
        var $list = $('#gastenboekList'), currentDate = '';
        $.each(data, function (index, bericht) {
            if (currentDate !== bericht.DatumNL) {
                currentDate = bericht.DatumNL;
                $list.append('<li data-role="list-divider" data-divider-theme="a">' + currentDate + '</li>');
            }

            $list.append('<li>'
            + '<h4>' + bericht.AuteurNaam + ' | ' + bericht.DatumNL + '</h4>'
            + '<p>' + bericht.BerichtHtml.fixGastenboekSmilies() + '</p>'
            + '</li>');
        });

        $('#gastenboekList').listview('refresh');
    }).error(function () { console.error('Fout bij aanspreken webservice'); });
}

function getNieuwsBericht(data) {
    $('#nieuwsDetails').jqmData('nieuws-id', data.ID);
    $('#nieuws-titel').text(data.Titel);
    $('#nieuws-datum').text(data.DatumNL);
    $('#nieuws-bericht').html(data.BerichtHtml);

    var $fotoGallery = $('#nieuws-bericht-fotos ul');
    $fotoGallery.empty();
    if (data.Fotos.length > 0) {
        $.each(data.Fotos, function (index, foto) {
            $fotoGallery.append('<li><a href="' + foto.UrlOrigineel + '" rel="external"><img src="' + foto.UrlOrigineel + '" /></a></li>');
        });
        $('a', $fotoGallery).photoSwipe({ loop: false });
    }

    $('#btnVorigNieuwsbericht, #btnVolgendNieuwsbericht').removeClass('ui-btn-active');
}

function getTweetsList() {
    var jsonSearchUrl = serviceURL + 'twitterstatus';
    $.getJSON(jsonSearchUrl, function (data) {
        $('#tweetsList li').remove();
        var $list = $('#tweetsList'), currentDate = '';
        $.each(data, function (index, tweet) {
            if (currentDate !== tweet.CreatedDate.parseTwitterDate()) {
                currentDate = tweet.CreatedDate.parseTwitterDate();
                $list.append('<li data-role="list-divider" data-divider-theme="a">' + currentDate + '</li>');
            }

            $list.append('<li>'
                + '<img class="ui-li-thumb" width="80" height="80" src="' + tweet.AuthorProfileImageUrl.replace('_normal', '_bigger') + '" />'
                + '<h4 style="margin: 0 0 6px;">' + tweet.AuthorScreenName + '</h4>'
                + '<p>' + tweet.TextAsHtml + '</p>'
                + '</a></li>');
        });

        $('#tweetsList').listview('refresh');
        $('#tweetsList li a').attr('rel', 'external');
    }).error(function () { console.error('Fout bij aanspreken webservice'); });
}

function getProgramma() {
    var url = serviceURL + 'wedstrijd';

    var parseData = function (data) {
        var $list = $('#programmaList'), currentDate = '';
        $list.empty();
        $.each(data, function (index, $wedstrijd) {
            var datum = $wedstrijd.DatumKort;

            if (datum !== currentDate) {
                currentDate = datum;
                $list.append('<li data-role="list-divider" data-divider-theme="a">' + datum.capitalize() + '</li>');
            }

            var aanvang, veld, teamThuis, teamUit, teamThuisId, teamUitId;
            aanvang = $wedstrijd.Aanvang;
            veld = $wedstrijd.Veld;
            teamThuis = $wedstrijd.TeamThuis;
            teamUit = $wedstrijd.TeamUit;
            teamThuisId = $wedstrijd.TeamThuisId;
            teamUitId = $wedstrijd.TeamUitId;

            var mijnTeam = localStorage.getItem('avd.settings.WpTeamID');
            var isMijnTeamClass = (teamThuisId == mijnTeam || teamUitId == mijnTeam) ? 'mijn-team' : '';

            $list.append('<li class="' + isMijnTeamClass + '"'
                 + ' data-datum="' + datum.capitalize() + '"'
                 + ' data-aanvang="' + aanvang + '"'
                 + ' data-scheids="' + $wedstrijd.Scheidsrechter + '"'
                 + ' data-kk-thuis="' + $wedstrijd.TeamThuisKleedkamer + '"'
                 + ' data-kk-uit="' + $wedstrijd.TeamUitKleedkamer + '"'
                 + ' data-veld="' + veld + '"'
                 + ' data-team-uit="' + teamUit + '"'
                 + ' data-team-thuis="' + teamThuis + '"'
                 + ' data-speelt-thuis="' + $wedstrijd.SpeeltThuis + '"'
                 + ' data-acc="' + $wedstrijd.Accommodatie + '"'
                + '><a><div class="ui-grid-c">'
                    + '<div class="ui-block-a">' + aanvang + '</div>'
                    + '<div class="ui-block-b">' + teamThuis + '</div>'
                    + '<div class="ui-block-c">' + teamUit + '</div>'
                    + '<div class="ui-block-d">' + veld + '</div>'
                + '</div></a>'
            + '</li>');
        });

        $('li .ui-grid-c', $list).highlightHonselersdijk();
        $('li a', $list).click(function () {
            var $detailsContent = $('#wedstrijd-details-content'),
                $headerH1 = $('#wedstrijd-details-header h1'),
                $li = $(this).closest('li');

            $headerH1.text($li.jqmData('datum'));
            var detailsHtml = '<h3>' +$li.jqmData('aanvang') + ': ' + $li.jqmData('teamThuis') + ' - ' +$li.jqmData('teamUit') + '</h3>'
                + '<ul data=role="listview">';
            if ($li.jqmData('scheids').length > 0)
                detailsHtml += '<li>Onder leiding van: ' +$li.jqmData('scheids') + '</li>';
            if ($li.jqmData('veld').length > 0)
                detailsHtml += '<li>Veld: ' +$li.jqmData('veld') + '</li>';
            if ($li.jqmData('kk-thuis').length > 0)
                detailsHtml += '<li>Kleedkamer thuisclub: ' +$li.jqmData('kk-thuis') + '</li>';
            if ($li.jqmData('kk-uit').length > 0)
                detailsHtml += '<li>Kleedkamer uitclub: ' +$li.jqmData('kk-uit') + '</li>'
            if ($li.jqmData('speelt-thuis') == '0')
                detailsHtml += '<li>Accomodatie: <a rel="external" href="http://maps.google.com?q=' + $li.jqmData('acc') + '">' +$li.jqmData('acc') + '</a></li>'
            detailsHtml += '</ul>';

            $detailsContent.html(detailsHtml);
            $.mobile.changePage('#wedstrijd-details');
        });

        $list.listview('refresh');
    };

    $.get(url).success(parseData).fail(function(e) { console.log(e); });
}

function getContactpersonenList() {
    $.getJSON(serviceURL + 'contactpersoon', function (data) {
        $('#contactpersonenList li').remove();
        $.each(data, function (index, persoon) {
            $('#contactpersonenList').append('<li>'
                + '<div class="ui-grid-a">'
                + '	<div class="ui-block-a">'
                    + persoon.Naam
                    + '<br><span style="font-weight: normal;">' +persoon.Functie + '</span>'
                + '</div>'
                + '	<div class="ui-block-b" style="font-weight: normal;">'
                + '   <a href="mailto:' +persoon.Email + '">' +persoon.Email + '</a>'
                + '   <br><a href="tel:' +persoon.Telefoonnummer + '">' +persoon.Telefoonnummer + '</a>'
                + '   <a href="tel:' + persoon.Mobiel + '">' +persoon.Mobiel + '</a>'
                + ' </div>'
                + '</div>'
                + '</li>');
            });

        $('#contactpersonenList').listview('refresh');
    }).error(function () { console.error('Fout bij aanspreken webservice'); });
}

$(document).bind("mobileinit", function() {
    console.log('mobileinit');
    $.support.cors = true;
    $.mobile.defaultPageTransition = 'none';
    $.mobile.allowCrossDomainPages = true;
    $.mobile.buttonMarkup.hoverDelay = 100;
    $.mobile.pageLoadErrorMessageTheme = 'a';
    $.mobile.pageLoadErrorMessage = 'Fout bij laden pagina';

    $.mobile.page.prototype.options.backBtnText = "Terug";
    $.mobile.page.prototype.options.addBackBtn = true;
    $.mobile.page.prototype.options.backBtnTheme = "a";
    $.mobile.page.prototype.options.headerTheme = "a";  // Page header only
    $.mobile.page.prototype.options.contentTheme = "a";
    $.mobile.page.prototype.options.footerTheme = "a";

    $.mobile.listview.prototype.options.headerTheme = "a"; // Header for nested lists
    $.mobile.listview.prototype.options.theme = "a"; // List items / content
    $.mobile.listview.prototype.options.dividerTheme = "a";  // List divider

    $.mobile.listview.prototype.options.splitTheme = "a";
    $.mobile.listview.prototype.options.countTheme = "a";
    $.mobile.listview.prototype.options.filterTheme = "a";
    $.mobile.listview.prototype.options.filterPlaceholder = "Zoeken...";

    initElftallenSelectList();

    $('#gastenboek').live('pageshow', getGastenboekList);
    $('#twitter').live('pageshow', getTweetsList);
    $('#programma').live('pageshow', getProgramma);
    $('#contactpersonen').live('pageinit', getContactpersonenList);
    $('#nieuws').live('pageshow', getNieuwsList);
    $('#team').live('pageinit', function() { $('#select-elftal').change(); });

    $('#nieuwsList li a').live('click', function(event) {
        var id = $(this).jqmData('nieuws-id');
            var url = serviceURL + 'nieuwsbericht/' + id;

            $.mobile.showPageLoadingMsg();
            $.getJSON(url, getNieuwsBericht)
                .error(function () { console.error('Fout bij aanspreken webservice'); })
                .done(function() { $.mobile.hidePageLoadingMsg(); });
                });

            $('#nieuwsDetails').live('pageinit', function() {
            console.log('pageinit nieuwsDetails');

            var navigate = function (vooruit) {
                $.mobile.showPageLoadingMsg();
                var id = $('#nieuwsDetails').jqmData('nieuws-id'),
                    $clickedLink = $('#nieuwsList').find("a[data-nieuws-id='" +id + "']"),
                    $parentLi = $clickedLink.closest('li'),
                    $nextLi = vooruit === - 1 ? $parentLi.prevAll('.ui-btn').first(): $parentLi.nextAll('.ui-btn').first(),
                    $nextLink = $nextLi.find('a');

                if($nextLink.length > 0) {
                    $nextLink.click();
                } else {
                    $.mobile.hidePageLoadingMsg();
                    }
                };

            $('#btnVorigNieuwsbericht').bind('click', function () { navigate(-1); });
            $('#btnVolgendNieuwsbericht').bind('click', function () { navigate(1); });
    });

    $('#select-elftal').live('change', function () {
        var $select = $(this);
        if($select.val() == '- Kies een team -')
            return;

        var url = serviceURL + 'elftal/' + $select.val();
        localStorage.setItem('avd.settings.WpTeamID', $select.val());
        $('#btnMijnTeam span').text('Mijn team - ' +$select.find('option:selected').text());

        var parseData = function (data) {
            console.log(data);
            var $container = $('#stand-container').empty();
            var $standList = $('<ul data-role="listview" data-inset="true"></ul>').appendTo($container).listview();
            var $uitslagenList = $('<ul data-role="listview" data-inset="true"></ul>').appendTo($container).listview();

            var teamNaam = data.Categorie;
            $standList.append('<li data-role="list-divider" data-divider-theme="a">' +teamNaam + '</li>');
            $.each(data.RanglijstItems, function(index, rang) {
                $standList.append('<li>'
                    + '  <div class="ui-grid-d">'
                    + '    <div class="ui-block-a" style="width: 60%;">' +rang.Positie + '. ' + rang.Team + '</div>'
                    + '    <div class="ui-block-b" style="width: 10%;">' +rang.Punten + '</div>'
                    + '    <div class="ui-block-c" style="width: 10%; font-weight: normal;">' +rang.Winst + '</div>'
                    + '    <div class="ui-block-d" style="width: 10%; font-weight: normal;">' +rang.Gelijkspel + '</div>'
                    + '    <div class="ui-block-e" style="width: 10%; font-weight: normal;">' +rang.Verlies + '</div>'
                    + '  </div>'
                    + '</li>');
                });

            var uitslagen = data.Uitslagen;
            if (uitslagen) {
                $uitslagenList.append('<li data-role="list-divider" data-divider-theme="a">Uitslagen</li>');
                $.each(uitslagen, function (index, uitslag) {
                    $uitslagenList.append('<li>'
                        + '  <div class="ui-grid-b">'
                        + '    <div class="ui-block-a" style="width: 40%;">' +uitslag.TeamThuis + '</div>'
                        + '    <div class="ui-block-b" style="width: 40%;">' +uitslag.TeamUit + '</div>'
                        + '    <div class="ui-block-c" style="width: 20%;">' +uitslag.Score + '</div>'
                        + '  </div>'
                        + '</li>');
                });
                }

            $standList.listview('refresh');
            $uitslagenList.listview('refresh');
            $('li > div', $container).highlightHonselersdijk();

            $.mobile.hidePageLoadingMsg();
            };

        $.mobile.showPageLoadingMsg();
        $.ajax({type: "GET", url: url, success: parseData}); });
    });